@@ -65,7 +65,7 @@ class Auth:
         self.validate_api_key(api_key)
         if not (self.api_key):
             attempts += 1
-            print(f"{PREFIX}Invalid API Key.\n")
+            print(f"{PREFIX}Invalid API key.\n")
 
             if attempts <= 3:
                 return self.attempt_api_key(attempts)
