@@ -6,7 +6,7 @@ from .config import REPO_URL, REPO_BRANCH, ENVIRONMENT
 
 
 def installDependencies():
-    print('Installing YOLOv5 Requirements...', end=" ")
+    print('Installing YOLOv5 🚀 requirements...', end=" ")
     if ENVIRONMENT == 'development':
         subprocess.call(['pip', 'install', '-r', 'yolov5/requirements.txt'])
     else:
@@ -23,7 +23,7 @@ def verifyInstall():
     if not os.path.isdir("./yolov5"):
         from git import Repo
         try:
-            print(f"Cloning YOLOv5 Repo from {REPO_URL}...", end=" ")
+            print(f"Cloning YOLOv5 🚀 from {REPO_URL}...", end=" ")
             Repo.clone_from(REPO_URL, "yolov5", branch=REPO_BRANCH
                             )  # Temp solution while waiting on pull request
             print("Done")
